pub struct FetchStateSummary {
pub pending_requests: HashMap<OpId, Vec<Url>>,
}Expand description
Summary of the fetch state.
Fields
pending_requests: HashMap<OpId, Vec<Url>>The op ids that are currently being fetched.
Each op id is associated with one or more peer URL from which the op data could be requested.