TxModuleHandler

Trait TxModuleHandler 

pub trait TxModuleHandler: TxBaseHandler {
    // Provided method
    fn recv_module_msg(
        &self,
        peer: Url,
        space_id: SpaceId,
        module: String,
        data: Bytes,
    ) -> K2Result<()> { ... }
}
Handler for module-related events.

Provided Methods

fn recv_module_msg( &self, peer: Url, space_id: SpaceId, module: String, data: Bytes, ) -> K2Result<()>

The sync handler for receiving module messages sent by a remote peer in reference to a particular space. If this callback returns an error, then the connection which sent the message will be closed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors